@@ -2,7 +2,7 @@ package Task::Plack;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 use ExtUtils::MakeMaker;
 
 use base qw(Exporter);
@@ -17,7 +17,7 @@ sub dependencies {
             [ 'Net::FastCGI' ],
         ],
         'Stacktrace with lexical variables', 0, [
-            [ 'Devel::StackTrace::WithLexicals' ],
+            [ 'Devel::StackTrace::WithLexicals', 0.08 ],
         ],
         'Utility to create IO::Handle-ish objects', 1, [
             [ 'IO::Handle::Util' ],
